OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "To-dos" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} tog bort kalender {calendar}",
    "You deleted calendar {calendar}" : "Du tog bort kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} återställde kalender {calendar}",
    "You restored calendar {calendar}" : "Du återställde kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "Untitled event" : "Namnlös händelse",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} tog bort händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du tog bort händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} flyttade händelse {event} från kalender {sourceCalendar} till kalender {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du flyttade händelse {event} från kalender {sourceCalendar} till kalender {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} återställde händelsen {event} i kalendern {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du återställde händelsen {event} i kalendern {calendar}",
    "Busy" : "Upptagen",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created to-do {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} tog bort uppgift {todo} från listan {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Du tog bort uppgift {todo} från listan {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontakter och uppgifter",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
    "A calendar <strong>to-do</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Contact birthdays" : "Födelsedagar",
    "Death of %s" : "Död av %s",
    "Untitled calendar" : "Namnlös kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
    "%s (in %s)" : "%s (på %s)",
    "%s (%s ago)" : "%s (%s sedan)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beskrivning: %s",
    "Where: %s" : "Var: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Avbruten: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" har avbrutits",
    "Re: %1$s" : "Sv: %1$s",
    "%1$s has accepted your invitation" : "%1$s har accepterat din inbjudan",
    "%1$s has tentatively accepted your invitation" : "%1$s har preliminärt accepterat din inbjudan",
    "%1$s has declined your invitation" : "%1$s har tackat nej till din inbjudan",
    "%1$s has responded to your invitation" : "%1$s har svarat på din inbjudan",
    "Invitation updated: %1$s" : "Inbjudan uppdaterad: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s uppdaterade händelse \"%2$s\"",
    "Invitation: %1$s" : "Inbjudan: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s skulle vilja bjuda in dig till \"%2$s\"",
    "Organizer:" : "Arrangör:",
    "Attendees:" : "Deltagare:",
    "Title:" : "Titel:",
    "Time:" : "Tid:",
    "Location:" : "Ort:",
    "Link:" : "Länk:",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "More options …" : "Fler alternativ ...",
    "More options at %s" : "Fler alternativ på %s",
    "Contacts" : "Kontakter",
    "{actor} created address book {addressbook}" : "{actor} skapade adressboken {addressbook}",
    "You created address book {addressbook}" : "Du skapade adressboken {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} tog bort adressboken {addressbook}",
    "You deleted address book {addressbook}" : "Du tog bort adressboken {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} uppdaterade adressboken {addressbook}",
    "You updated address book {addressbook}" : "Du uppdaterade adressboken {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} delade adressboken {addressbook} med dig",
    "You shared address book {addressbook} with {user}" : "Du delade adressboken {addressbook} med {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} delade adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} slutade dela adressboken {addressbook} med dig",
    "You unshared address book {addressbook} from {user}" : "Du slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} tog bort delning adressboken {addressbook} från sig själv",
    "You shared address book {addressbook} with group {group}" : "Du delade adressboken {addressbook} med gruppen {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} delade adressboken {addressbook} med gruppen {group}",
    "You unshared address book {addressbook} from group {group}" : "Du slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} skapade kontakten {card} i adressboken {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Du skapade kontakten {card} i adressboken {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} tog bort kontakten {card} från adressboken {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Du tog bort kontakten {©ard} från adressboken {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} uppdaterade kontakten {card} i adressboken {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Du uppdaterade kontakten {card} i adressboken {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressbok</strong> ändrades",
    "File is not updatable: %1$s" : "Fil kan inte uppdateras: %1$s",
    "Could not write to final file, canceled by hook" : "Kunde ej skriva till den slutgiltiga filen, avbröts av en kopplad åtgärd",
    "Could not write file contents" : "Kunde inte skriva filens innehåll",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fel vid kopiering av fil till målplats (kopierade: %1$s, förväntad filstorlek: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Förväntad filstorlek på %1$s men läste (från Nextcloud-klienten) och skrev (till Nextcloud-lagringen) %2$s. Kan antingen vara ett nätverksproblem på sändnings-sidan eller problem med att skriva till lagringen på server-sidan.",
    "Could not rename part file to final file, canceled by hook" : "Kunde inte byta namn på filfragment till slutgiltigt filnamn, avbröts av en kopplad åtgärd.",
    "Could not rename part file to final file" : "Kunde inte ändra namn från temporära filen till slutliga filen",
    "Failed to check file size: %1$s" : "Kunde inte kontrollera filstorleken: %1$s",
    "Could not open file" : "Kunde inte öppna fil",
    "Encryption not ready: %1$s" : "Kryptering ej redo: %1$s",
    "Failed to open file: %1$s" : "Kunde inte öppna fil: %1$s",
    "Failed to unlink: %1$s" : "Kunde inte ta bort: %1$s",
    "Invalid chunk name" : "Ogiltigt delnamn",
    "Could not rename part file assembled from chunks" : "Kunde inte ändra namn på temporära filen ihopsatt från delar",
    "Failed to write file contents: %1$s" : "Kunde inte skriva filinnehåll: %1$s",
    "File not found: %1$s" : "Filen hittades inte: %1$s",
    "System is in maintenance mode." : "Systemet är i underhållsläge.",
    "Upgrade needed" : "Uppdatering nödvändig",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s måste konfigureras att använda HTTPS för CalDAV och CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
    "Events" : "Händelser",
    "Tasks" : "Uppgifter",
    "Untitled task" : "Namnlös uppgift",
    "Completed on %s" : "Slutförd %s",
    "Due on %s by %s" : "Slutar den %s vid %s",
    "Due on %s" : "Slutar den %s",
    "Migrated calendar (%1$s)" : "Migrerade kalender (%1$s)",
    "Calendars including events, details and attendees" : "Kalendrar inklusive händelser, detaljer och deltagare",
    "Contacts and groups" : "Kontakter och grupper",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Availability" : "Tillgänglighet",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstimmar kan andra användare se när du inte är på jobbet när de bokar ett möte.",
    "Time zone:" : "Tidszon:",
    "to" : "till",
    "Delete slot" : "Radera lucka",
    "No working hours set" : "Inga arbetstimmar satta",
    "Add slot" : "Lägg till lucka",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sunday" : "Söndag",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sätt automatiskt användarstatus till \"Stör ej\" utanför tillgängliga tider för att tysta alla notifikationer.",
    "Save" : "Spara",
    "Failed to load availability" : "Misslyckades med att ladda tidsluckor",
    "Saved availability" : "Sparade tidslucka",
    "Failed to save availability" : "Misslyckades med att spara tidslucka",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
    "Send notifications for events" : "Skicka aviseringar för händelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
    "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
    "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
    "Enable notifications for events via push" : "Aktivera aviseringar för händelser via push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}Kalender-app{linkclose}, eller {calendardocopen}anslut din dator & mobil för synkronisering ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Verifiera och säkerställ inställningar för {emailopen}e-postserver{linkclose}.",
    "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
    "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
    "Are you accepting the invitation?" : "Acceptera inbjudan?",
    "Tentative" : "Preliminärt",
    "Your attendance was updated successfully." : "Dina närvaro uppdaterades.",
    "Todos" : "Uppgifter",
    "{actor} created todo {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created todo {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} tog bort uppgift {todo} från listan {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du tog bort uppgift {todo} från listan {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Invitation canceled" : "Inbjudan avbruten",
    "Invitation updated" : "Inbjudan uppdaterad",
    "Invitation" : "Inbjudan"
},
"nplurals=2; plural=(n != 1);");
